# Generated by Django 5.0.7 on 2024-07-30 20:05

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_service", "0005_apppermission_created_at_apppermission_status_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServiceApps",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Date and time on which the object was created",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        help_text="Date and time on which the object was updated",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "status",
                    models.BooleanField(
                        default=True,
                        help_text="Status of the object",
                        verbose_name="Status",
                    ),
                ),
                (
                    "apps",
                    models.ManyToManyField(
                        related_name="services", to="artd_service.installedapp"
                    ),
                ),
                (
                    "service",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="apps",
                        to="artd_service.service",
                    ),
                ),
            ],
            options={
                "verbose_name": "Service Apps",
                "verbose_name_plural": "Service Appss",
            },
        ),
    ]
